Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src fix various typos, mainly in comments, but also log messages...



details:   https://anonhg.NetBSD.org/src/rev/3b1c8068d28d
branches:  trunk
changeset: 364710:3b1c8068d28d
user:      andvar <andvar%NetBSD.org@localhost>
date:      Fri Apr 08 10:17:52 2022 +0000

description:
fix various typos, mainly in comments, but also log messages, docs, game text.

diffstat:

 bin/csh/err.c                                         |   6 +++---
 etc/MAKEDEV.tmpl                                      |   4 ++--
 games/fortune/datfiles/limerick-o.real                |   2 +-
 games/warp/warp.h                                     |   2 +-
 lib/libc/arch/aarch64/gen/flt_rounds.c                |   8 ++++----
 lib/libc/arch/arm/gen/flt_rounds.c                    |   6 +++---
 lib/libc/arch/sh3/gen/flt_rounds.c                    |   6 +++---
 lib/libcurses/screen.c                                |   6 +++---
 regress/lib/libc/ieeefp/testfloat/notes/testfloat.txt |   4 ++--
 sbin/fsck_v7fs/inode.c                                |   8 ++++----
 sbin/ping6/ping6.c                                    |   6 +++---
 sbin/resize_ffs/resize_ffs.c                          |   6 +++---
 sys/arch/acorn32/podulebus/if_ie.c                    |   6 +++---
 sys/arch/epoc32/stand/e32boot/ldd/ekern.h             |   2 +-
 sys/arch/hpcmips/vr/vrc4172pcsreg.h                   |   4 ++--
 sys/arch/hpcmips/vr/vrc4172reg.h                      |   4 ++--
 sys/arch/m68k/fpsp/round.sa                           |   6 +++---
 sys/arch/m68k/fpsp/util.sa                            |   4 ++--
 sys/arch/m68k/fpsp/x_store.sa                         |   4 ++--
 sys/arch/macppc/dev/fcu.c                             |   6 +++---
 sys/arch/mips/alchemy/include/aureg.h                 |   4 ++--
 sys/arch/mips/mips/cache_r3k_subr.S                   |   4 ++--
 sys/arch/mips/mips/cache_r5k_subr.S                   |   4 ++--
 sys/arch/shark/shark/scr.c                            |   8 ++++----
 sys/arch/vax/include/ka650.h                          |   4 ++--
 sys/dev/fdt/dw_apb_uart.c                             |   8 ++++----
 sys/dev/isa/README.seagate                            |   4 ++--
 sys/dev/lockstat.c                                    |   6 +++---
 sys/dev/pcmcia/if_xi.c                                |   6 +++---
 sys/kern/kern_sleepq.c                                |   6 +++---
 sys/netinet/sctp_output.c                             |  12 ++++++------
 usr.bin/pr/pr.c                                       |   6 +++---
 usr.sbin/edquota/edquota.8                            |   4 ++--
 usr.sbin/lpr/lpd/lpd.c                                |   6 +++---
 usr.sbin/lpr/lpq/lpq.c                                |   6 +++---
 usr.sbin/sysinst/partman.c                            |   4 ++--
 36 files changed, 96 insertions(+), 96 deletions(-)

diffs (truncated from 865 to 300 lines):

diff -r ba11884dc80c -r 3b1c8068d28d bin/csh/err.c
--- a/bin/csh/err.c     Fri Apr 08 05:47:33 2022 +0000
+++ b/bin/csh/err.c     Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: err.c,v 1.24 2021/09/11 20:55:03 christos Exp $ */
+/* $NetBSD: err.c,v 1.25 2022/04/08 10:17:52 andvar Exp $ */
 
 /*-
  * Copyright (c) 1980, 1991, 1993
@@ -34,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)err.c      8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: err.c,v 1.24 2021/09/11 20:55:03 christos Exp $");
+__RCSID("$NetBSD: err.c,v 1.25 2022/04/08 10:17:52 andvar Exp $");
 #endif
 #endif /* not lint */
 
@@ -313,7 +313,7 @@
  *               in bname
  *
  * This routine always resets or exits.  The flag haderr
- * is set so the routine who catches the unwind can propogate
+ * is set so the routine who catches the unwind can propagate
  * it if they want.
  *
  * Note that any open files at the point of error will eventually
diff -r ba11884dc80c -r 3b1c8068d28d etc/MAKEDEV.tmpl
--- a/etc/MAKEDEV.tmpl  Fri Apr 08 05:47:33 2022 +0000
+++ b/etc/MAKEDEV.tmpl  Fri Apr 08 10:17:52 2022 +0000
@@ -1,5 +1,5 @@
 #!/bin/sh -
-#      $NetBSD: MAKEDEV.tmpl,v 1.228 2021/12/07 17:39:53 brad Exp $
+#      $NetBSD: MAKEDEV.tmpl,v 1.229 2022/04/08 10:17:52 andvar Exp $
 #
 # Copyright (c) 2003,2007,2008 The NetBSD Foundation, Inc.
 # All rights reserved.
@@ -443,7 +443,7 @@
        do_update=false
        opts=
        while getopts Mfm:p:st:u ch; do
-               # Note that $opts is only for options pased through to
+               # Note that $opts is only for options passed through to
                # MAKEDEV.local, not for all options.
                case ${ch} in
                M)
diff -r ba11884dc80c -r 3b1c8068d28d games/fortune/datfiles/limerick-o.real
--- a/games/fortune/datfiles/limerick-o.real    Fri Apr 08 05:47:33 2022 +0000
+++ b/games/fortune/datfiles/limerick-o.real    Fri Apr 08 10:17:52 2022 +0000
@@ -3057,7 +3057,7 @@
 And cried: "For that I'll be a martyr!"
 %
 There once was a lady named Clair,
-Who posessed a magnificent pair.
+Who possessed a magnificent pair.
        Or that's what I thought,
        Till I saw one get caught,
 On a thorn and begin losing air.
diff -r ba11884dc80c -r 3b1c8068d28d games/warp/warp.h
--- a/games/warp/warp.h Fri Apr 08 05:47:33 2022 +0000
+++ b/games/warp/warp.h Fri Apr 08 10:17:52 2022 +0000
@@ -55,7 +55,7 @@
 #define WARPMACRO "%X/Kbmap.%{TERM}"
 
 /* warp library */
-#ifndef WARPLIB                /* ~ and %l only ("~%l" is permissable) */
+#ifndef WARPLIB                /* ~ and %l only ("~%l" is permissible) */
 #   ifdef PRIVLIB
 #      define WARPLIB PRIVLIB
 #   else
diff -r ba11884dc80c -r 3b1c8068d28d lib/libc/arch/aarch64/gen/flt_rounds.c
--- a/lib/libc/arch/aarch64/gen/flt_rounds.c    Fri Apr 08 05:47:33 2022 +0000
+++ b/lib/libc/arch/aarch64/gen/flt_rounds.c    Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: flt_rounds.c,v 1.1 2014/08/10 05:47:36 matt Exp $ */
+/* $NetBSD: flt_rounds.c,v 1.2 2022/04/08 10:17:52 andvar Exp $ */
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include <sys/cdefs.h>
 #if defined(LIBC_SCCS) && !defined(lint)
-__RCSID("$NetBSD: flt_rounds.c,v 1.1 2014/08/10 05:47:36 matt Exp $");
+__RCSID("$NetBSD: flt_rounds.c,v 1.2 2022/04/08 10:17:52 andvar Exp $");
 #endif /* LIBC_SCCS and not lint */
 
 #include <sys/param.h>
@@ -47,12 +47,12 @@
  * Returns:
  *     0 - round to zero
  *     1 - round to nearest
- *     2 - round to postive infinity
+ *     2 - round to positive infinity
  *     3 - round to negative infinity
  *
  * However, the rounding modes stored in the FPCR are:
  *     0 - round to nearest
- *     1 - round to postive infinity
+ *     1 - round to positive infinity
  *     2 - round to negative infinity
  *     3 - round to zero
  *
diff -r ba11884dc80c -r 3b1c8068d28d lib/libc/arch/arm/gen/flt_rounds.c
--- a/lib/libc/arch/arm/gen/flt_rounds.c        Fri Apr 08 05:47:33 2022 +0000
+++ b/lib/libc/arch/arm/gen/flt_rounds.c        Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: flt_rounds.c,v 1.5 2015/03/19 21:22:59 joerg Exp $     */
+/*     $NetBSD: flt_rounds.c,v 1.6 2022/04/08 10:17:52 andvar Exp $    */
 
 /*
  * Copyright (c) 1996 Mark Brinicombe
@@ -33,7 +33,7 @@
 
 #include <sys/cdefs.h>
 #if defined(LIBC_SCCS) && !defined(lint)
-__RCSID("$NetBSD: flt_rounds.c,v 1.5 2015/03/19 21:22:59 joerg Exp $");
+__RCSID("$NetBSD: flt_rounds.c,v 1.6 2022/04/08 10:17:52 andvar Exp $");
 #endif /* LIBC_SCCS and not lint */
 
 #include "namespace.h"
@@ -53,7 +53,7 @@
  * Returns:
  *     0 - round to zero
  *     1 - round to nearest
- *     2 - round to postive infinity
+ *     2 - round to positive infinity
  *     3 - round to negative infinity
  *
  * ok all we need to do is get the current FP rounding mode
diff -r ba11884dc80c -r 3b1c8068d28d lib/libc/arch/sh3/gen/flt_rounds.c
--- a/lib/libc/arch/sh3/gen/flt_rounds.c        Fri Apr 08 05:47:33 2022 +0000
+++ b/lib/libc/arch/sh3/gen/flt_rounds.c        Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: flt_rounds.c,v 1.7 2017/03/11 01:25:04 chs Exp $       */
+/*     $NetBSD: flt_rounds.c,v 1.8 2022/04/08 10:17:52 andvar Exp $    */
 
 /*
  * Copyright (c) 1996 Mark Brinicombe
@@ -33,7 +33,7 @@
 
 #include <sys/cdefs.h>
 #if defined(LIBC_SCCS) && !defined(lint)
-__RCSID("$NetBSD: flt_rounds.c,v 1.7 2017/03/11 01:25:04 chs Exp $");
+__RCSID("$NetBSD: flt_rounds.c,v 1.8 2022/04/08 10:17:52 andvar Exp $");
 #endif /* LIBC_SCCS and not lint */
 
 #include "namespace.h"
@@ -53,7 +53,7 @@
  * Returns:
  *     0 - round to zero
  *     1 - round to nearest
- *     2 - round to postive infinity
+ *     2 - round to positive infinity
  *     3 - round to negative infinity
  *
  * ok all we need to do is get the current FP rounding mode
diff -r ba11884dc80c -r 3b1c8068d28d lib/libcurses/screen.c
--- a/lib/libcurses/screen.c    Fri Apr 08 05:47:33 2022 +0000
+++ b/lib/libcurses/screen.c    Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: screen.c,v 1.36 2021/09/06 07:03:50 rin Exp $  */
+/*     $NetBSD: screen.c,v 1.37 2022/04/08 10:17:52 andvar Exp $       */
 
 /*
  * Copyright (c) 1981, 1993, 1994
@@ -34,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)screen.c   8.2 (blymn) 11/27/2001";
 #else
-__RCSID("$NetBSD: screen.c,v 1.36 2021/09/06 07:03:50 rin Exp $");
+__RCSID("$NetBSD: screen.c,v 1.37 2022/04/08 10:17:52 andvar Exp $");
 #endif
 #endif                                 /* not lint */
 
@@ -152,7 +152,7 @@
        new_screen->echoit = new_screen->nl = 1;
        new_screen->pfast = new_screen->rawmode = new_screen->noqch = 0;
        new_screen->filtered = filtered;
-       filtered = FALSE; /* filter() must preceed each newterm() */
+       filtered = FALSE; /* filter() must precede each newterm() */
        new_screen->nca = A_NORMAL;
        new_screen->color_type = COLOR_NONE;
        new_screen->COLOR_PAIRS = 0;
diff -r ba11884dc80c -r 3b1c8068d28d regress/lib/libc/ieeefp/testfloat/notes/testfloat.txt
--- a/regress/lib/libc/ieeefp/testfloat/notes/testfloat.txt     Fri Apr 08 05:47:33 2022 +0000
+++ b/regress/lib/libc/ieeefp/testfloat/notes/testfloat.txt     Fri Apr 08 10:17:52 2022 +0000
@@ -289,7 +289,7 @@
 representable integer of the desired size (32 or 64 bits).  If such a
 conversion overflows, TestFloat expects the largest integer with the same
 sign as the operand to be returned.  If the floating-point operand is a NaN,
-TestFloat allows either the largest postive or largest negative integer to
+TestFloat allows either the largest positive or largest negative integer to
 be returned.
 
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -629,7 +629,7 @@
 exception if the source value cannot be rounded to a representable integer.
 When the conversion overflows, TestFloat expects the largest integer with
 the same sign as the operand to be returned.  If the floating-point operand
-is a NaN, TestFloat allows either the largest postive or largest negative
+is a NaN, TestFloat allows either the largest positive or largest negative
 integer to be returned.  The current version of TestFloat provides no means
 to alter these conventions.
 
diff -r ba11884dc80c -r 3b1c8068d28d sbin/ping6/ping6.c
--- a/sbin/ping6/ping6.c        Fri Apr 08 05:47:33 2022 +0000
+++ b/sbin/ping6/ping6.c        Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ping6.c,v 1.106 2021/06/11 18:47:56 rillig Exp $       */
+/*     $NetBSD: ping6.c,v 1.107 2022/04/08 10:17:53 andvar Exp $       */
 /*     $KAME: ping6.c,v 1.164 2002/11/16 14:05:37 itojun Exp $ */
 
 /*
@@ -77,7 +77,7 @@
 #else
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: ping6.c,v 1.106 2021/06/11 18:47:56 rillig Exp $");
+__RCSID("$NetBSD: ping6.c,v 1.107 2022/04/08 10:17:53 andvar Exp $");
 #endif
 #endif
 
@@ -1006,7 +1006,7 @@
 
                        /*
                         * receive control messages only. Process the
-                        * exceptions (currently the only possiblity is
+                        * exceptions (currently the only possibility is
                         * a path MTU notification.)
                         */
                        if ((mtu = get_pathmtu(&m)) > 0) {
diff -r ba11884dc80c -r 3b1c8068d28d sbin/resize_ffs/resize_ffs.c
--- a/sbin/resize_ffs/resize_ffs.c      Fri Apr 08 05:47:33 2022 +0000
+++ b/sbin/resize_ffs/resize_ffs.c      Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: resize_ffs.c,v 1.55 2020/05/24 14:41:26 jmcneill Exp $ */
+/*     $NetBSD: resize_ffs.c,v 1.56 2022/04/08 10:17:53 andvar Exp $   */
 /* From sources sent on February 17, 2003 */
 /*-
  * As its sole author, I explicitly place this code in the public
@@ -36,7 +36,7 @@
  */
 
 #include <sys/cdefs.h>
-__RCSID("$NetBSD: resize_ffs.c,v 1.55 2020/05/24 14:41:26 jmcneill Exp $");
+__RCSID("$NetBSD: resize_ffs.c,v 1.56 2022/04/08 10:17:53 andvar Exp $");
 
 #include <sys/disk.h>
 #include <sys/disklabel.h>
@@ -1072,7 +1072,7 @@
 }
 /*
  * Call (*fn)() for each inode, passing the inode and its inumber.  The
- *  number of cylinder groups is pased in, so this can be used to map
+ *  number of cylinder groups is passed in, so this can be used to map
  *  over either the old or the new file system's set of inodes.
  */
 static void
diff -r ba11884dc80c -r 3b1c8068d28d sys/arch/acorn32/podulebus/if_ie.c
--- a/sys/arch/acorn32/podulebus/if_ie.c        Fri Apr 08 05:47:33 2022 +0000
+++ b/sys/arch/acorn32/podulebus/if_ie.c        Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ie.c,v 1.51 2021/11/10 16:44:42 msaitoh Exp $ */
+/* $NetBSD: if_ie.c,v 1.52 2022/04/08 10:17:53 andvar Exp $ */



Home | Main Index | Thread Index | Old Index
diff -r ba11884dc80c -r 3b1c8068d28d sbin/fsck_v7fs/inode.c
--- a/sbin/fsck_v7fs/inode.c    Fri Apr 08 05:47:33 2022 +0000
+++ b/sbin/fsck_v7fs/inode.c    Fri Apr 08 10:17:52 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: inode.c,v 1.1 2011/06/27 11:52:58 uch Exp $    */
+/*     $NetBSD: inode.c,v 1.2 2022/04/08 10:17:53 andvar Exp $ */
 
 /*-
  * Copyright (c) 2011 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: inode.c,v 1.1 2011/06/27 11:52:58 uch Exp $");
+__RCSID("$NetBSD: inode.c,v 1.2 2022/04/08 10:17:53 andvar Exp $");
 #endif /* not lint */
 
 #include <sys/types.h>
@@ -94,14 +94,14 @@
        return FSCK_EXIT_OK;
 }
 
 /* Counting freeinode and find partialy allocated inode. */
 static int
 v7fs_inode_check(struct v7fs_self *fs, struct v7fs_inode *p, v7fs_ino_t ino)
 {
        int error = 0;
 
        if (v7fs_inode_allocated(p) && !p->nlink) {
-               pwarn("*** partialy allocated inode #%d", ino);
+               pwarn("*** partially allocated inode #%d", ino);
                v7fs_inode_dump(p);
                if (reply_trivial("REMOVE?")) {
                        memset(p, 0, sizeof(*p));
@@ -94,14 +94,14 @@
 }
 
-/* Counting freeinode and find partialy allocated inode. */
+/* Counting freeinode and find partially allocated inode. */
 static int
 v7fs_inode_check(struct v7fs_self *fs, struct v7fs_inode *p, v7fs_ino_t ino)